.. _node:

Node
====

The :class:`scherbelberg.Node` class describes one node, i.e. server, within the cluster. It can represent both, a Dask worker node as well as a Dask scheduler node, see `Dask CLI`_ for more details.

.. _Dask CLI: https://docs.dask.org/en/stable/deploying-cli.html

The ``Node`` Class
------------------

.. autoclass:: scherbelberg.Node
    :members:
